@@ -100,6 +100,13 @@ from .services.vendor_knowledgebase import VendorKnowledgeBaseService
 from .services.vendor_guardrail import VendorGuardrailService
 from .services.codemie_guardrails import CodemieGuardrailService
 from .services.analytics import AnalyticsService
+from .models.mermaid import (
+    MermaidDiagramRequest,
+    MermaidDiagramResponse,
+    ContentType,
+    ResponseType,
+)
+from .services.mermaid import MermaidService
 
 __version__ = "0.2.12"
 __all__ = [
@@ -174,4 +181,9 @@ __all__ = [
     "AnalyticsQueryParams",
     "PaginatedAnalyticsQueryParams",
     "AnalyticsService",
+    "MermaidDiagramRequest",
+    "MermaidDiagramResponse",
+    "ContentType",
+    "ResponseType",
+    "MermaidService",
 ]
